/* _dict.cc 14/07/1999 21.33.44 */
/* debian.cc 28/08/2000 18.12.06 */
PUBLIC MODULE_debian::MODULE_debian (void);
PUBLIC void MODULE_debian::setmenu (DIALOG&dia, MENU_CONTEXT context);
PUBLIC int MODULE_debian::domenu (MENU_CONTEXT context,
	 const char *key);
PUBLIC int MODULE_debian::dohtml (const char *key);
PUBLIC void MODULE_debian::usage (SSTRINGS&tb);
PUBLIC int MODULE_debian::execmain (int argc, char *argv[], bool);
/* filter.cc 07/08/2000 11.34.24 */
PRIVATE void CONFDB_DEBIAN::reset_modified (void);
PUBLIC CONFDB_DEBIAN::CONFDB_DEBIAN (CONFDB *_orig);
PUBLIC CONFDB_DEBIAN::~CONFDB_DEBIAN (void);
PUBLIC void CONFDB_DEBIAN::setcursys (const char *_subsys);
PUBLIC int CONFDB_DEBIAN::save (PRIVILEGE *priv);
PRIVATE const char *CONFDB_DEBIAN::getextval (DEBIAN_CONFIG_ITEM *dci);
PRIVATE void CONFDB_DEBIAN::setextval (DEBIAN_CONFIG_ITEM *dci,
	 const char *val);
PUBLIC const char *CONFDB_DEBIAN::getval (const char *prefix,
	 const char *key,
	 const char *defval);
PUBLIC int CONFDB_DEBIAN::getall (const char *prefix,
	 const char *key,
	 SSTRINGS&lst,
	 bool copy);
PUBLIC void CONFDB_DEBIAN::removeall (const char *prefix,
	 const char *key);
PUBLIC void CONFDB_DEBIAN::add (const char *prefix,
	 const char *key,
	 const char *val);
PUBLIC int CONFDB_DEBIAN::archive (SSTREAM&ss, const char *_sys);
PUBLIC int CONFDB_DEBIAN::extract (SSTREAM&ss, const char *_sys);
/* menu.cc 14/07/1999 21.33.44 */
/* pam.cc 21/08/2000 22.37.22 */
/* user.cc 12/12/1999 22.29.04 */
